@@ -24,7 +24,7 @@ import os
 import shlex
 import logging
 import re
-from .utils import find_mount_source, LvmCLI
+from .utils import find_mount_source, LvmCLI, ExternalBinary
 
 
 log = logging.getLogger(__package__)
@@ -47,6 +47,7 @@ class LVM(object):
     _lvextend = LvmCLI.lvextend
     _vgcreate = LvmCLI.vgcreate
     _vgchange = LvmCLI.vgchange
+    _lvmconfig = LvmCLI.lvmconfig
 
     @staticmethod
     def _list_lv_full_names(filtr=""):
@@ -89,6 +90,11 @@ class LVM(object):
 
         return True
 
+    @staticmethod
+    def stop_monitoring():
+        LVM._vgchange(["--monitor", "n"])
+        ExternalBinary().pkill(["dmeventd"])
+
     class VG(object):
         vg_name = None
 
@@ -262,6 +268,13 @@ class LVM(object):
             lv_name = self.options(["origin"]).pop()
             return LVM.LV.from_lv_name(self.vg_name, lv_name)
 
+        def profile(self):
+            return self.options(["lv_profile"]).pop()
+
+        def set_profile(self, name, config=None):
+            args = ["--config", config] if config else []
+            LVM._lvchange(args + ["--metadataprofile", name, self.lvm_name])
+
         def options(self, options):
             sep = "$"
             cmd = ["--noheadings",
